PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/quadrature.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

quadrature.h
Go to the documentation of this file.
1
5 #ifndef QUADRATURE_H
6 #define QUADRATURE_H
7
8 extern double QUADRATURE_POINTS[98][101];
9 extern double QUADRATURE_WEIGHTS[98][101];
10
11 #endif
QUADRATURE_WEIGHTS
double QUADRATURE_WEIGHTS[98][101]
QUADRATURE_POINTS
double QUADRATURE_POINTS[98][101]